AlternativeService class

Finds healthier alternative packages for high-risk dependencies.

Constructors

AlternativeService(PubApiClient _api)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findBetterAlternatives(PackageMetadata original) Future<List<String>>
Given a PackageMetadata that has high risk, searches for similar packages and returns a list of names that have better health metrics.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited