fresh property
When true, bypasses the disk cache and fetches fresh data from the
network even if a valid cached entry exists.
Implementation
final bool fresh;
When true, bypasses the disk cache and fetches fresh data from the
network even if a valid cached entry exists.
final bool fresh;