UpdateService class
Automated service to update pubspec.yaml to the highest mutually compatible versions.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String pubspecPath) → Future< void> -
Resolves the latest highest compatible versions and rewrites
pubspec.yaml.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited