Urls class abstract

Base URLs for the external APIs pub_doctor talks to.

Constructors

Urls()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

githubApi → const String
Root of the GitHub REST API (v3/2022-11-28).
pubDevApi → const String
Root of the pub.dev REST API (v2).