clearAll method
Deletes all cached entries by removing the cache directory entirely.
Implementation
Future<void> clearAll() async {
final dir = Directory(_dir);
if (await dir.exists()) await dir.delete(recursive: true);
}
Deletes all cached entries by removing the cache directory entirely.
Future<void> clearAll() async {
final dir = Directory(_dir);
if (await dir.exists()) await dir.delete(recursive: true);
}