DiskCache class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> -
get(
String key) → Future< Map< String, dynamic> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
String key, Map< String, dynamic> data, {Duration ttl = const Duration(hours: 24)}) → Future<void> -
stats(
) → Future< ({int bytes, int entries})> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited