GitHubClient class

Wraps the GitHub API and converts raw JSON into RepoHealth objects.

Constructors

GitHubClient({Client? client, DiskCache? cache, Duration timeout = const Duration(seconds: 10)})
Creates a GitHubClient.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Closes the underlying HTTP client.
fetchRepoHealth(Uri repoUrl) Future<RepoHealth?>
Fetches RepoHealth for the GitHub repository at repoUrl.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited