Release class

A single version-and-publication-date pair from a package's release history.

Constructors

Release({required Version version, required DateTime publishedAt})
Creates a Release.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
publishedAt DateTime
When this version was published to pub.dev.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version → Version
The semver version string for this release.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited