avgIssueCloseTimeDays property
Average days from issue open to close across the last 100 closed issues.
Implementation
final double? avgIssueCloseTimeDays;
Average days from issue open to close across the last 100 closed issues.
final double? avgIssueCloseTimeDays;